@@ -1,5 +1,4 @@
 ### R code from vignette source 'ground-control-to-ruimtehol.Rnw'
-### Encoding: ISO8859-1
 
 ###################################################
 ### code chunk number 1: preliminaries
@@ -31,7 +30,7 @@ dekamer$y[1:2]
 
 
 ###################################################
-### code chunk number 4: ground-control-to-ruimtehol.Rnw:115-122
+### code chunk number 4: ground-control-to-ruimtehol.Rnw:115-123
 ###################################################
 set.seed(321)
 model <- embed_tagspace(x = dekamer$x, y = dekamer$y, 
@@ -39,23 +38,24 @@ model <- embed_tagspace(x = dekamer$x, y = dekamer$y,
                         dim = 50, 
                         lr = 0.01, epoch = 40, loss = "softmax", adagrad = TRUE, 
                         similarity = "cosine", negSearchLimit = 50,
-                        ngrams = 2, minCount = 2)
+                        ngrams = 2, minCount = 2,
+                        maxTrainTime = 2 * 60)
 
 
 ###################################################
-### code chunk number 5: ground-control-to-ruimtehol.Rnw:124-125
+### code chunk number 5: ground-control-to-ruimtehol.Rnw:125-126
 ###################################################
 model
 
 
 ###################################################
-### code chunk number 6: ground-control-to-ruimtehol.Rnw:144-145
+### code chunk number 6: ground-control-to-ruimtehol.Rnw:146-147
 ###################################################
 plot(model)
 
 
 ###################################################
-### code chunk number 7: ground-control-to-ruimtehol.Rnw:151-154
+### code chunk number 7: ground-control-to-ruimtehol.Rnw:153-156
 ###################################################
 dict <- starspace_dictionary(model)
 str(dict)
@@ -63,14 +63,14 @@ length(dict$labels)
 
 
 ###################################################
-### code chunk number 8: ground-control-to-ruimtehol.Rnw:163-165
+### code chunk number 8: ground-control-to-ruimtehol.Rnw:165-167
 ###################################################
 emb <- as.matrix(model)
 dim(emb)
 
 
 ###################################################
-### code chunk number 9: ground-control-to-ruimtehol.Rnw:170-173
+### code chunk number 9: ground-control-to-ruimtehol.Rnw:172-175
 ###################################################
 emb_words  <- as.matrix(model, type = "words")
 emb_labels <- as.matrix(model, type = "labels", prefix = FALSE)
@@ -78,13 +78,13 @@ e <- starspace_embedding(model, x = c("__label__VERVOERBELEID", "geld"), type =
 
 
 ###################################################
-### code chunk number 10: ground-control-to-ruimtehol.Rnw:178-179
+### code chunk number 10: ground-control-to-ruimtehol.Rnw:180-181
 ###################################################
 e <- starspace_embedding(model, c("nationale loterij"), type = "ngram")
 
 
 ###################################################
-### code chunk number 11: ground-control-to-ruimtehol.Rnw:186-190
+### code chunk number 11: ground-control-to-ruimtehol.Rnw:188-192
 ###################################################
 text <- c("de nmbs heeft het treinaanbod uitgebreid via onteigening ...",
           "de migranten komen naar europa de asielcentra ...")
@@ -93,25 +93,25 @@ dim(emb_text)
 
 
 ###################################################
-### code chunk number 12: ground-control-to-ruimtehol.Rnw:197-198
+### code chunk number 12: ground-control-to-ruimtehol.Rnw:199-200
 ###################################################
 predict(model, "de migranten komen naar europa de asielcentra ...")
 
 
 ###################################################
-### code chunk number 13: ground-control-to-ruimtehol.Rnw:203-204
+### code chunk number 13: ground-control-to-ruimtehol.Rnw:205-206
 ###################################################
 embedding_similarity(emb_text, emb_labels, type = "cosine", top_n = 5)
 
 
 ###################################################
-### code chunk number 14: ground-control-to-ruimtehol.Rnw:209-210
+### code chunk number 14: ground-control-to-ruimtehol.Rnw:211-212
 ###################################################
 starspace_knn(model, "de migranten komen naar europa de asielcentra ...", k = 5)
 
 
 ###################################################
-### code chunk number 15: ground-control-to-ruimtehol.Rnw:217-230
+### code chunk number 15: ground-control-to-ruimtehol.Rnw:219-232
 ###################################################
 targetdocs <- c("__label__FISCALITEIT", 
                 "__label__OVERHEIDSADMINISTRATIE", 
@@ -129,20 +129,20 @@ embedding_similarity(
 
 
 ###################################################
-### code chunk number 16: ground-control-to-ruimtehol.Rnw:238-240
+### code chunk number 16: ground-control-to-ruimtehol.Rnw:240-242
 ###################################################
 starspace_save_model(model, file = "textspace.ruimtehol")
 model <- starspace_load_model("textspace.ruimtehol")
 
 
 ###################################################
-### code chunk number 17: ground-control-to-ruimtehol.Rnw:243-244
+### code chunk number 17: ground-control-to-ruimtehol.Rnw:245-246
 ###################################################
 invisible(file.remove("textspace.ruimtehol"))
 
 
 ###################################################
-### code chunk number 18: ground-control-to-ruimtehol.Rnw:260-272
+### code chunk number 18: ground-control-to-ruimtehol.Rnw:262-275
 ###################################################
 set.seed(321)
 dekamer <- dekamer[order(rnorm(n = nrow(dekamer))), ]
@@ -155,11 +155,12 @@ model <- embed_tagspace(x = X, y = Y,
                         dim = 50, 
                         lr = 0.01, epoch = 40, loss = "softmax", adagrad = TRUE, 
                         similarity = "cosine", negSearchLimit = 50,
-                        ngrams = 2, minCount = 2)
+                        ngrams = 2, minCount = 2,
+                        maxTrainTime = 2 * 60)
 
 
 ###################################################
-### code chunk number 19: ground-control-to-ruimtehol.Rnw:295-300
+### code chunk number 19: ground-control-to-ruimtehol.Rnw:298-303
 ###################################################
 pretrained <- matrix(data = rnorm(1000 * 100), nrow = 1000, ncol = 100, 
                      dimnames = list(term = sprintf("word%s", 1:1000)))
@@ -169,17 +170,18 @@ predict(model, newdata = c("word5 word1 word5 word3"), type = "knn")
 
 
 ###################################################
-### code chunk number 20: ground-control-to-ruimtehol.Rnw:306-311
+### code chunk number 20: ground-control-to-ruimtehol.Rnw:309-315
 ###################################################
 set.seed(321)
 model <- embed_wordspace(dekamer$x, 
                          dim = 50, ws = 7, epoch = 5, ngrams = 2, adagrad = FALSE,
-                         margin = 0.8, negSearchLimit = 10)
+                         margin = 0.8, negSearchLimit = 10,
+                         maxTrainTime = 2 * 60)
 pretrained_words  <- as.matrix(model)
 
 
 ###################################################
-### code chunk number 21: ground-control-to-ruimtehol.Rnw:316-324
+### code chunk number 21: ground-control-to-ruimtehol.Rnw:320-328
 ###################################################
 labels            <- sort(unique(unlist(dekamer$y)))
 pretrained_labels <- matrix(data = rnorm(n = length(labels) * 50, 
@@ -192,7 +194,7 @@ pretrained        <- rbind(pretrained_words, pretrained_labels)
 
 
 ###################################################
-### code chunk number 22: ground-control-to-ruimtehol.Rnw:330-339
+### code chunk number 22: ground-control-to-ruimtehol.Rnw:334-344
 ###################################################
 set.seed(321)
 model <- embed_tagspace(x = dekamer$x, y = dekamer$y, 
@@ -201,12 +203,13 @@ model <- embed_tagspace(x = dekamer$x, y = dekamer$y,
                         dim = 50, 
                         lr = 0.01, epoch = 40, loss = "softmax", adagrad = TRUE, 
                         similarity = "cosine", negSearchLimit = 50,
-                        ngrams = 2, minCount = 2)
+                        ngrams = 2, minCount = 2,
+                        maxTrainTime = 2 * 60)
 embedding <- as.matrix(model)
 
 
 ###################################################
-### code chunk number 23: ground-control-to-ruimtehol.Rnw:342-344
+### code chunk number 23: ground-control-to-ruimtehol.Rnw:347-349
 ###################################################
 plot(model)
 starspace_knn(model, "__label__FISCALITEIT", k = 10)
